@@ -19,7 +19,7 @@ class WeakNetworkConfig(object):
     ATC_SHAPE_URI = "/api/v1/shape/{}/"
 
     def __init__(self, atc_host="http://172.29.182.152:8000", stf_url=None, sft_token=None, wifi_name="yy_net",
-                 wifi_password=""):
+                 wifi_password="", weak_network_ip="192.168.1"):
         """
             :param atc_host: atc服务地址
             :param stf_url: sft服务器地址
@@ -38,6 +38,7 @@ class WeakNetworkConfig(object):
         self._device_list = []
         self._device_ip_list = []
         self.platform = None
+        self.weak_network_ip = weak_network_ip
 
     def _get_device_info(self, serial):
         """
@@ -90,7 +91,7 @@ class WeakNetworkConfig(object):
             self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
             ip = self._stf.get_android_device_ip(serial)
             logger.info("get_android_device_ip :{} return ip :{}".format(serial, ip))
-            if str(ip).startswith("192.168.0"):
+            if str(ip).startswith(self.weak_network_ip):
                 self.set_auth(ip)
                 return ip
             else:
@@ -116,7 +117,7 @@ class WeakNetworkConfig(object):
             logger.info("get device_ip {}".format(device_ip))
             if device_ip:
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
-                if device_ip.startswith('192.168.0'):
+                if device_ip.startswith(self.weak_network_ip):
                     self.set_auth(device_ip)
                     return device_ip
                 else:
